SaveFileExtensionBehavior enum

Determines what to do if the file extension does not match the mime type.

Inheritance
Available extensions

Values

replace → const SaveFileExtensionBehavior

Replace the extension (i.e. the part after the last '.') with the correct one.

append → const SaveFileExtensionBehavior

Append the correct extension. Note that this may result in a file with two extensions (i.e. file.jpg.png).

ignore → const SaveFileExtensionBehavior

Ignore the extension mismatch. Note that file may become unreadable.

fail → const SaveFileExtensionBehavior

Throw SaveFileExtensionException.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SaveFileExtensionBehavior>
A constant List of the values in this enum, in order of their declaration.