UtopiaSaveFile class sealed

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromAsset(String key, {String? mime, String? name, SaveFileExtensionBehavior extensionBehavior = SaveFileExtensionBehavior.replace}) Future<bool>
Copies asset at key to a location where it's accessible by the user.
fromBytes(List<int> bytes, {required String mime, required String name, SaveFileExtensionBehavior extensionBehavior = SaveFileExtensionBehavior.replace}) Future<bool>
Saves provided bytes to file in a location accessible by the user.
fromByteStream(Stream<List<int>> stream, {required String mime, required String name, SaveFileExtensionBehavior extensionBehavior = SaveFileExtensionBehavior.replace}) Future<bool>
Saves provided byte stream to file in a location accessible by the user.
fromFile(XFile file, {String? mime, String? name, SaveFileExtensionBehavior extensionBehavior = SaveFileExtensionBehavior.replace}) Future<bool>
Copies provided file to a location where it's accessible by the user.
fromUrl(String url, {String? name, String? mime, SaveFileExtensionBehavior extensionBehavior = SaveFileExtensionBehavior.replace}) Future<bool>
Downloads file from the provided url and saves it to a location where it's accessible by the user.